from em_tasks.utils.pipelines.base import BasePipeline
from em_tasks.utils.product_converters import AmzProductConverter

from em_tasks import logger


class AmzProductsFilterPipeline(BasePipeline):
  def __init__(self, marketplace = 'us', weight_max = 2.5, sales_rank_min = 1500000):
    self.weight_max = weight_max
    self.sales_rank_min = sales_rank_min
    self.pc = AmzProductConverter(marketplace.lower())

  def execute(self, product):
    exist = product.get('existence', True)
    if not exist:
      logger.debug('[NotExist]')
      return

    has_only_default_variant = product.get('has_only_default_variant', True)
    if not has_only_default_variant:
      logger.debug('[MultipleVariant]')
      return

    weight = self.pc.get_weight(product)
    if weight and weight > self.weight_max:
      logger.debug('[OverWeight] %s', weight)
      return

    is_fragile = self.pc.is_fragile(product)
    if is_fragile:
      logger.debug('[Fragile]')
      return

    sales_rank = self.pc.get_sales_rank(product)
    if sales_rank and sales_rank > self.sales_rank_min:
      logger.debug('[SalesRankLow] %s', sales_rank)
      return

    return product
